@@ -12,15 +12,15 @@
 #' \tabular{ll}{
 #'   \code{key}\tab \code{[character|integer]} index to column that uniquely identifies a row.\cr
 #'   \code{verbose}\tab \code{[logical]} toggle verbosity.\cr
-#'   \code{file}\tab [character] filename for temporaty log storage. \cr
+#'   \code{tempfile}\tab [character] filename for temporaty log storage. \cr
 #' }
 #' 
 #' @usage 
-#' cellwise(key, verbose=TRUE, file=tempfile())
+#' cellwise(key, verbose=TRUE, tempfile=file.path(tempdir(),"cellwise.csv"))
 #'
 #' @param key \code{[character|integer]} index to column that uniquely identifies a row.
 #' @param verbose  \code{[logical]} toggle verbosity.
-#' @param file  \code{[character]} filename for temporaty log storage.
+#' @param tempfile  \code{[character]} filename for temporaty log storage.
 #'
 #' @section Dump options:
 #'
@@ -44,7 +44,7 @@
 #' \code{\link{dump_log}} is called, the temporary file is closed, copied to
 #' the output file, and reopened for writing. The connection is closed
 #' automatically when the logger is destroyed, for example when calling
-#' \code{\link{dump_log}()}.
+#' \code{\link{stop_log}()}.
 #' 
 #' @docType class
 #' @format An \code{R6} class object.
@@ -54,20 +54,22 @@
 #' @family loggers
 #' @export
 cellwise <- R6Class("cellwise"
-  , public = list(
+  , private = list(
     tmpfile   = NULL
     , con     = NULL
     , n       = NULL 
     , verbose = NULL
     , label   = NULL
     , key     = NULL
-  , initialize = function(key, verbose=TRUE, file=file.path(tempdir(),"cellwise.csv")){
+  )
+  , public = list(
+    initialize = function(key, verbose=TRUE, tempfile=file.path(tempdir(),"cellwise.csv")){
       if(missing(key)) stop("you must provide a key")
-      self$tmpfile = file
-      self$con = file(self$tmpfile, open="wt")
-      self$n <- 0
-      self$verbose <- verbose
-      self$key <- key
+      private$tmpfile = tempfile
+      private$con = file(private$tmpfile, open="wt")
+      private$n <- 0
+      private$verbose <- verbose
+      private$key <- key
       write.csv(
         data.frame(
           step=integer(0)
@@ -78,50 +80,50 @@ cellwise <- R6Class("cellwise"
           , old=character(0)
           , new=character(0)
         )
-        , file=self$con
+        , file=private$con
         , row.names=FALSE
       )
   }
   , stop = function(...){
-       self$con <- iclose(self$con)
+       private$con <- iclose(private$con)
   }
   , add = function(meta, input, output){
-      if (!is_open(self$con)) return()
-      self$n <- self$n+1
+      if (!is_open(private$con)) return()
+      private$n <- private$n+1
       # timestamp
       ts <- strftime(Sys.time(),usetz=TRUE)
-      d <- celldiff(input, output, self$key)
+      d <- celldiff(input, output, private$key)
       if (nrow(d) == 0) return()
-      d$step <- self$n
+      d$step <- private$n
       d$time <- ts
       d$expression <- meta$src
       d <- d[c(5:7,1:4)]
-      write.table(d,file = self$con
+      write.table(d,file = private$con
             , row.names=FALSE, col.names=FALSE, sep=",")
   }
   , dump = function(file=NULL){
-      self$con <- iclose(self$con)
+      private$con <- iclose(private$con)
       if (is.null(file)){ 
         file <- "cellwise.csv" 
-        if (!is.null(self$label) && self$label != "" ) file <- paste(self$label,file,sep="_")
+        if (!is.null(private$label) && private$label != "" ) file <- paste(private$label,file,sep="_")
       }
-      file.copy(from=self$tmpfile, to=file, overwrite = TRUE)
-      if (self$verbose){
+      file.copy(from=private$tmpfile, to=file, overwrite = TRUE)
+      if (private$verbose){
         msgf("Dumped a log at %s",file)
       }
   }
   , finalize = function(){
-    if (is_open(self$con)) close(self$con)
+    if (is_open(private$con)) close(private$con)
   }
   , logdata = function(){
-     read.csv(self$tmpfile)
+     read.csv(private$tmpfile)
   }
   )
 )
 
 # A reasonable connection closer
 iclose <- function(con,...){
-  close(con,...)
+  if (!is.null(con)) close(con,...)
   invisible(NULL)
 }
 
@@ -152,6 +154,10 @@ keyframe <- function(x, key){
 }
 
 celldiff <- function(x,y,key){
+  if ( anyDuplicated(x[,key]) || anyDuplicated(y[,key]) ){
+    warnf("Detected duplicates in key variable '%s'. Logging data corrupted.",key)
+  }
+  
   kx <- keyframe(x,key)
   ky <- keyframe(y,key)
   kxy <- merge(kx,ky,by=c("key","variable"), all=TRUE)
