@@ -15,7 +15,7 @@ i2 <- head(women) %>>%
         dump_log(file=logfile)
 expect_true(file.exists(logfile))
 logger <- simple$new()
-iris %>>% start_log(logger) %>>% head() %>>% stop_log()
+iris %>>% start_log(logger) %>>% head() %>>% stop_log(dump=FALSE)
 expect_equal(nrow(logger$logdata()), 1L)
 
 
